@@ -1,11 +1,11 @@
 #pragma once
-#define GIT_COMMIT_HASH    "0002f148c9a4fe421a9d33c0faa5528cdc411e62"
-#define GIT_BRANCH         "v0.54.0"
-#define GIT_COMMIT_MESSAGE "version: bump to 0.54.0"
-#define GIT_COMMIT_DATE    "Fri Feb 27 18:03:19 2026"
+#define GIT_COMMIT_HASH    "4b07770b9ef1cceb2e6f56d33538aaffb9186b9c"
+#define GIT_BRANCH         "v0.54.1"
+#define GIT_COMMIT_MESSAGE "[gha] Nix: update inputs"
+#define GIT_COMMIT_DATE    "Tue Mar 3 21:06:41 2026"
 #define GIT_DIRTY          "clean"
-#define GIT_TAG            "v0.54.0"
-#define GIT_COMMITS        "6935"
+#define GIT_TAG            "v0.54.1"
+#define GIT_COMMITS        "6979"
 
 #define AQUAMARINE_VERSION "0.10.0"
 // clang-format off
